#include <libint2.h>
#ifdef __cplusplus
extern "C" {
#endif
void HRRPart1bra0ket0mh(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, int highdim);
#ifdef __cplusplus
};
#endif
